## dbt-adapters 1.17.3 - October 20, 2025

### Under the Hood

- Remove `catalog` from `RelationConfig` protocol and update base build_catalog_relation to obtain catalog_name from node config ([#1376](https://github.com/dbt-labs/dbt-adapters/issues/1376))
- Record all fields in subclasses of BaseColumns when recording adapter.get_columns_in_relation ([#1383](https://github.com/dbt-labs/dbt-adapters/issues/1383))
